DataPrioritizer

Trait DataPrioritizer 

pub trait DataPrioritizer {
    // Required method
    fn get_next_chunk(&mut self) -> HttpResult<Option<DataChunk<'_>>>;
}
A trait that types that want to provide data to an HTTP/2 connection need to implement.

Required Methods

fn get_next_chunk(&mut self) -> HttpResult<Option<DataChunk<'_>>>

Returns the next DataChunk that should be sent on the HTTP/2 connection. None indicates that currently there was no data that could be sent at that point.

Implementors

Source

impl<'a, 'b, State> DataPrioritizer for SimplePrioritizer<'a, 'b, State>
where State: SessionState + 'a,