pub enum StreamDataChunk {
Chunk(usize),
Last(usize),
Unavailable,
}Expand description
The enum represents the successful completion of the Stream::get_data_chunk method.
Variants
Chunk(usize)
A data chunk of the given size, after which more chunks can follow.
Last(usize)
The chunk was the last one that the stream will ever write.
No data currently available, but the stream isn’t closed yet